@@ -150,7 +150,7 @@ class DatabaseManager:
         if self.settings['auto_parse']:
             # @Mstep [if] compare the saved modified timestamp to the current timestamp.
             if _has_master_changed(self):
-                _log("Master SQL has been modified, initiating auto parsing.")
+                print("Master SQL has been modified, initiating auto parsing.")
                 self.parse_master_sql(
                     self.master_sql_path,
                     create_dir=self.create_dir,
@@ -158,7 +158,7 @@ class DatabaseManager:
                     skip_no_schema=self.skip_orphans
                 )
             else:
-                _log("Master SQL has not been modified since last parse.")
+                print("Master SQL has not been modified since last parse.")
             # self.gen_creates()
 
         self.save_master_summary()
@@ -1498,8 +1498,10 @@ class DatabaseManager:
                 # print(f"executing sql: ",sql)
                 self.cur.execute(sql)
             else:
-                args = _csu.sql.sanitize_quotes(args)
+                
+                args = _sanitize_args(args)
                 self.cur.execute(sql, args)
+                
                 # print(f"result: ",result)
 
             self.con.commit()
@@ -2418,103 +2420,14 @@ def _parse_master_summary_file(main:DatabaseManager):
     return True
 
 
-# def _remove_table_data_dict(main:DatabaseManager,table_name:str)->bool:
-#     '''
-#         Remove a table data dictionary from the database Managers tables list.
-#         This will remove any tables that match the table_name provided.
-#         Then update DatabaseManager.data['table'] with the updated list.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `main` {DatabaseManager}
-#             A reference to the DatabaseManager
-#         `table_name` {str}
-#             The name of the table to remove.
-
-#         Return {bool}
-#         ----------------------
-#         True upon success, false otherwise.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-07-2022 11:09:38
-#         `memberOf`: DatabaseManager
-#         `version`: 1.0
-#         `method_name`: _remove_table_data_dict
-#         * @xxx [06-07-2022 11:11:03]: documentation for _remove_table_data_dict
-#     '''
-
-
-#     new_tables = []
-#     match_found = False
-#     for table in main.tables:
-#         if table['table_name'] != table_name:
-#             new_tables.append(table)
-#         else:
-#             match_found = True
-#     main.settings['tables'] = new_tables
-#     return match_found
-
-
-# def _delete_table_instance(main:DatabaseManager,table_names:_Union[list,str],schema:_Union[str,None]=None)->bool:
-#     '''
-#         Remove a table manager instance.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `main` {DatabaseManager}
-#             A reference to the DatabaseManager
-
-#         `table_name` {list|str}
-#             The name of the table to remove.
-
-#         [`schema`=None] {str}
-#             If provided, the matching table must also belong to this schema.
-
-#         Return {bool}
-#         ----------------------
-#         True upon success, false otherwise.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-07-2022 11:27:05
-#         `memberOf`: DatabaseManager
-#         `version`: 1.0
-#         `method_name`: _delete_table_instance
-#         * @xxx [06-07-2022 11:29:13]: documentation for _delete_table_instance
-#     '''
-
-
-#     table_names = _lu.force_list(table_names)
-#     new_tables = []
-#     match_found = False
-#     for table_name in table_names:
-
-#         table_name = _csu.to_snake_case(table_name)
-#         t:_table_manager.TableManager
-#         for t in main.data['table_instances']:
-#             if schema is not None:
-#                 if t['schema_name'] == schema:
-#                     if t.table_name != table_name:
-#                         new_tables.append(t)
-#                         continue
-#                     else:
-#                         _remove_table_data_dict(main,table_name)
-#                         # print(f"Deleting table instance: {table_name}")
-#                         match_found = True
-#             if t.table_name != table_name:
-#                 # print(_Fore.GREEN + f"Keeping {t.name}" + _Style.RESET_ALL)
-#                 new_tables.append(t)
-#             else:
-#                 _remove_table_data_dict(main,table_name)
-#                 # print(_Fore.RED + f"Deleting {t.name}" + _Style.RESET_ALL)
-#                 # print(f"Deleting table instance: {table_name}")
-#                 match_found = True
-#     main.data['table_instances'] = new_tables
-#     return match_found
+def _sanitize_args(args):
+    if isinstance(args,(dict)):
+        output = {}
+        for k,v in args.items():
+            output[k] = _csu.sanitize_quotes(v)
+        return output
+    if isinstance(args,(list)):
+        output = []
+        for v in args:
+            output.append(_csu.sanitize_quotes(v))
+        return output
