@@ -23,6 +23,7 @@ from colorama import Style as _Style
 import colemen_utilities.list_utils as _lu
 import colemen_utilities.string_utils as _csu
 import collections
+from collections.abc import MutableMapping
 
 def set_defaults(default_vals, obj,**kwargs):
     '''
@@ -732,7 +733,7 @@ def flatten(d, parent_key='', sep='.'):
     items = []
     for k, v in d.items():
         new_key = parent_key + sep + k if parent_key else k
-        if isinstance(v, collections.MutableMapping):
+        if isinstance(v, MutableMapping):
             items.extend(flatten(v, new_key, sep=sep).items())
         else:
             items.append((new_key, v))
